plone.app.event.portlets.portlet_events — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.portlets.portlet_events

class `plone.app.event.portlets.portlet_events.` `Assignment`(count=5, state=None, search_base=None)

  Base class for assignments.

  Your type may override the ‘title’, ‘available’ and ‘data’ properties, and may

class `plone.app.event.portlets.portlet_events.` `Renderer`(*args)

  Base class for portlet renderers.

  You must override render() to return a string to render. One way of doing this is to write:

  > from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile ... render = ViewPageTemplateFile(‘mytemplate.pt’)

  This will render the template mytemplate.pt, found in the same directory as your source code file.

### Navigation

- index
- modules |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »